@@ -117,7 +117,7 @@ import org.apache.commons.lang3.StringUtils;
  * @since 1.0
  *
  * @author <a href="mailto:ebourg@apache.org">Emmanuel Bourg</a>
- * @version $Id: DatabaseConfiguration.java 1735895 2016-03-20 18:40:47Z oheger $
+ * @version $Id: DatabaseConfiguration.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class DatabaseConfiguration extends AbstractConfiguration
 {
@@ -333,7 +333,7 @@ public class DatabaseConfiguration extends AbstractConfiguration
                         openResultSet(String.format(SQL_GET_PROPERTY,
                                 table, keyColumn), true, key);
 
-                List<Object> results = new ArrayList<Object>();
+                List<Object> results = new ArrayList<>();
                 while (rs.next())
                 {
                     Object value = extractPropertyValue(rs);
@@ -559,7 +559,7 @@ public class DatabaseConfiguration extends AbstractConfiguration
     @Override
     protected Iterator<String> getKeysInternal()
     {
-        final Collection<String> keys = new ArrayList<String>();
+        final Collection<String> keys = new ArrayList<>();
         new JdbcOperation<Collection<String>>(ConfigurationErrorEvent.READ,
                 ConfigurationErrorEvent.READ, null, null)
         {
