@@ -189,7 +189,7 @@ import org.xml.sax.helpers.DefaultHandler;
  *
  * @since commons-configuration 1.0
  * @author J&ouml;rg Schaible
- * @version $Id: XMLConfiguration.java 1779753 2017-01-21 20:21:41Z oheger $
+ * @version $Id: XMLConfiguration.java 1799980 2017-06-26 20:21:16Z oheger $
  */
 public class XMLConfiguration extends BaseHierarchicalConfiguration implements
         FileBasedConfiguration, FileLocatorAware, InputStreamSupport
@@ -556,7 +556,7 @@ public class XMLConfiguration extends BaseHierarchicalConfiguration implements
         setSystemID(docHelper.getSourceSystemID());
 
         ImmutableNode.Builder rootBuilder = new ImmutableNode.Builder();
-        MutableObject<String> rootValue = new MutableObject<String>();
+        MutableObject<String> rootValue = new MutableObject<>();
         Map<ImmutableNode, Object> elemRefMap =
                 elemRefs ? new HashMap<ImmutableNode, Object>() : null;
         Map<String, String> attributes =
@@ -607,7 +607,7 @@ public class XMLConfiguration extends BaseHierarchicalConfiguration implements
                 ImmutableNode.Builder childNode = new ImmutableNode.Builder();
                 childNode.name(child.getTagName());
                 MutableObject<String> refChildValue =
-                        new MutableObject<String>();
+                        new MutableObject<>();
                 Map<String, String> attrmap =
                         constructHierarchy(childNode, refChildValue, child,
                                 elemRefs, trimFlag, level + 1);
@@ -669,7 +669,7 @@ public class XMLConfiguration extends BaseHierarchicalConfiguration implements
     private static Map<String, String> processAttributes(Element element)
     {
         NamedNodeMap attributes = element.getAttributes();
-        Map<String, String> attrmap = new HashMap<String, String>();
+        Map<String, String> attrmap = new HashMap<>();
 
         for (int i = 0; i < attributes.getLength(); ++i)
         {
@@ -1124,7 +1124,7 @@ public class XMLConfiguration extends BaseHierarchicalConfiguration implements
             document = docHelper.getDocument();
             elementMapping = docHelper.getElementMapping();
             listDelimiterHandler = handler;
-            newElements = new HashMap<ImmutableNode, Element>();
+            newElements = new HashMap<>();
         }
 
         /**
@@ -1166,7 +1166,7 @@ public class XMLConfiguration extends BaseHierarchicalConfiguration implements
                 ImmutableNode sibling1, ImmutableNode sibling2,
                 ReferenceNodeHandler refHandler)
         {
-            if(XMLListReference.isListNode(newNode, refHandler))
+            if (XMLListReference.isListNode(newNode, refHandler))
             {
                 return;
             }
@@ -1207,9 +1207,9 @@ public class XMLConfiguration extends BaseHierarchicalConfiguration implements
         protected void update(ImmutableNode node, Object reference,
                 ReferenceNodeHandler refHandler)
         {
-            if(XMLListReference.isListNode(node, refHandler))
+            if (XMLListReference.isListNode(node, refHandler))
             {
-                if(XMLListReference.isFirstListItem(node, refHandler))
+                if (XMLListReference.isFirstListItem(node, refHandler))
                 {
                     String value = XMLListReference.listValue(node, refHandler, listDelimiterHandler);
                     updateElement(node, refHandler, value);
@@ -1308,7 +1308,7 @@ public class XMLConfiguration extends BaseHierarchicalConfiguration implements
                         ((XMLDocumentHelper) reference).getDocument()
                                 .getDocumentElement();
             }
-            else if(reference instanceof XMLListReference)
+            else if (reference instanceof XMLListReference)
             {
                 element = ((XMLListReference) reference).getElement();
             }
@@ -1372,7 +1372,7 @@ public class XMLConfiguration extends BaseHierarchicalConfiguration implements
             // Find all Text nodes
             NodeList children = elem.getChildNodes();
             Collection<org.w3c.dom.Node> textNodes =
-                    new ArrayList<org.w3c.dom.Node>();
+                    new ArrayList<>();
             for (int i = 0; i < children.getLength(); i++)
             {
                 org.w3c.dom.Node nd = children.item(i);
