@@ -80,7 +80,7 @@ import org.apache.commons.lang3.text.StrSubstitutor;
  * or removed at any time concurrent to interpolation operations.
  * </p>
  *
- * @version $Id: ConfigurationInterpolator.java 1745634 2016-05-26 19:12:33Z oheger $
+ * @version $Id: ConfigurationInterpolator.java 1790899 2017-04-10 21:56:46Z ggregory $
  * @since 1.4
  * @author <a
  *         href="http://commons.apache.org/configuration/team-list.html">Commons
@@ -117,8 +117,8 @@ public class ConfigurationInterpolator
      */
     public ConfigurationInterpolator()
     {
-        prefixLookups = new ConcurrentHashMap<String, Lookup>();
-        defaultLookups = new CopyOnWriteArrayList<Lookup>();
+        prefixLookups = new ConcurrentHashMap<>();
+        defaultLookups = new CopyOnWriteArrayList<>();
         substitutor = initSubstitutor();
     }
 
@@ -193,7 +193,7 @@ public class ConfigurationInterpolator
      */
     public Map<String, Lookup> getLookups()
     {
-        return new HashMap<String, Lookup>(prefixLookups);
+        return new HashMap<>(prefixLookups);
     }
 
     /**
@@ -275,7 +275,7 @@ public class ConfigurationInterpolator
      */
     public List<Lookup> getDefaultLookups()
     {
-        return new ArrayList<Lookup>(defaultLookups);
+        return new ArrayList<>(defaultLookups);
     }
 
     /**
@@ -545,7 +545,7 @@ public class ConfigurationInterpolator
 
     static
     {
-        Map<String, Lookup> lookups = new HashMap<String, Lookup>();
+        Map<String, Lookup> lookups = new HashMap<>();
         for (DefaultLookups l : DefaultLookups.values())
         {
             lookups.put(l.getPrefix(), l.getLookup());
