@@ -61,7 +61,7 @@ import org.junit.rules.TemporaryFolder;
 /**
  * Test class for CombinedConfiguration.
  *
- * @version $Id: TestCombinedConfiguration.java 1624601 2014-09-12 18:04:36Z oheger $
+ * @version $Id: TestCombinedConfiguration.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class TestCombinedConfiguration
 {
@@ -1014,7 +1014,7 @@ public class TestCombinedConfiguration
         final int writeCount = 3000;
         CountDownLatch latch = new CountDownLatch(1);
         AtomicInteger errorCount = new AtomicInteger();
-        Collection<Thread> threads = new ArrayList<Thread>(numberOfReaders + 1);
+        Collection<Thread> threads = new ArrayList<>(numberOfReaders + 1);
         Thread writeThread =
                 new WriteThread(config, latch, errorCount, writeCount);
         writeThread.start();
