@@ -49,7 +49,7 @@ import org.junit.Test;
 /**
  * Test class for {@code CompositeConfiguration}.
  *
- * @version $Id: TestCompositeConfiguration.java 1745638 2016-05-26 19:53:21Z oheger $
+ * @version $Id: TestCompositeConfiguration.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class TestCompositeConfiguration
 {
@@ -306,7 +306,7 @@ public class TestCompositeConfiguration
         // we should get 3 packages here
         assertEquals(3, packages.size());
 
-        List<Object> defaultList = new ArrayList<Object>();
+        List<Object> defaultList = new ArrayList<>();
         defaultList.add("1");
         defaultList.add("2");
 
@@ -374,12 +374,12 @@ public class TestCompositeConfiguration
     public void testGetKeysPreservesOrder() throws Exception
     {
         cc.addConfiguration(conf1);
-        List<String> orderedList = new ArrayList<String>();
+        List<String> orderedList = new ArrayList<>();
         for (Iterator<String> keys = conf1.getKeys(); keys.hasNext();)
         {
             orderedList.add(keys.next());
         }
-        List<String> iteratedList = new ArrayList<String>();
+        List<String> iteratedList = new ArrayList<>();
         for (Iterator<String> keys = cc.getKeys(); keys.hasNext();)
         {
             iteratedList.add(keys.next());
@@ -398,12 +398,12 @@ public class TestCompositeConfiguration
     public void testGetKeys2PreservesOrder() throws Exception
     {
         cc.addConfiguration(conf1);
-        List<String> orderedList = new ArrayList<String>();
+        List<String> orderedList = new ArrayList<>();
         for (Iterator<String> keys = conf1.getKeys("test"); keys.hasNext();)
         {
             orderedList.add(keys.next());
         }
-        List<String> iteratedList = new ArrayList<String>();
+        List<String> iteratedList = new ArrayList<>();
         for (Iterator<String> keys = cc.getKeys("test"); keys.hasNext();)
         {
             iteratedList.add(keys.next());
@@ -512,7 +512,7 @@ public class TestCompositeConfiguration
     @Test
     public void testInstanciateWithCollection()
     {
-        Collection<Configuration> configs = new ArrayList<Configuration>();
+        Collection<Configuration> configs = new ArrayList<>();
         configs.add(xmlConf);
         configs.add(conf1);
         configs.add(conf2);
