@@ -31,6 +31,7 @@ import java.io.PrintWriter;
 import java.io.StringReader;
 import java.io.StringWriter;
 import java.io.Writer;
+import java.text.MessageFormat;
 import java.util.Arrays;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -40,6 +41,7 @@ import java.util.Set;
 import org.apache.commons.configuration2.SynchronizerTestImpl.Methods;
 import org.apache.commons.configuration2.builder.FileBasedBuilderParametersImpl;
 import org.apache.commons.configuration2.builder.FileBasedConfigurationBuilder;
+import org.apache.commons.configuration2.builder.fluent.Parameters;
 import org.apache.commons.configuration2.convert.DefaultListDelimiterHandler;
 import org.apache.commons.configuration2.ex.ConfigurationException;
 import org.apache.commons.configuration2.sync.ReadWriteSynchronizer;
@@ -55,7 +57,7 @@ import org.junit.rules.TemporaryFolder;
 /**
  * Test class for {@code INIConfiguration}.
  *
- * @version $Id: TestINIConfiguration.java 1739471 2016-04-16 15:02:02Z oheger $
+ * @version $Id: TestINIConfiguration.java 1806819 2017-08-31 16:03:06Z oheger $
  */
 public class TestINIConfiguration
 {
@@ -95,6 +97,12 @@ public class TestINIConfiguration
             + "  line 2" + LINE_SEPARATOR
             + "continueNoLine = one \\" + LINE_SEPARATOR;
 
+    private static final String INI_DATA4 = "[section6]" + LINE_SEPARATOR
+    		+ "key1{0}value1" + LINE_SEPARATOR
+    		+ "key2{0}value2" + LINE_SEPARATOR + LINE_SEPARATOR
+    		+ "[section7]" + LINE_SEPARATOR
+    		+ "key3{0}value3" + LINE_SEPARATOR;
+
     private static final String INI_DATA_SEPARATORS = "[section]"
             + LINE_SEPARATOR + "var1 = value1" + LINE_SEPARATOR
             + "var2 : value2" + LINE_SEPARATOR
@@ -222,6 +230,29 @@ public class TestINIConfiguration
         assertEquals("Wrong content of ini file", INI_DATA, writer.toString());
     }
 
+    /**
+     * Test of save method with changed separator
+     */
+    @Test
+    public void testSeparatorUsedInINIOutput() throws Exception
+    {
+    	final String outputSeparator = ": ";
+    	String input = MessageFormat.format(INI_DATA4, "=").trim();
+    	String expectedOutput = MessageFormat.format(INI_DATA4, outputSeparator).trim();
+
+    	INIConfiguration instance = new FileBasedConfigurationBuilder<>(
+    	        INIConfiguration.class)
+                .configure(new Parameters().ini().setSeparatorUsedInOutput(outputSeparator))
+                .getConfiguration();
+        load(instance, input);
+
+        Writer writer = new StringWriter();
+        instance.write(writer);
+        String result = writer.toString().trim();
+
+        assertEquals("Wrong content of ini file", expectedOutput, result);
+    }
+
     /**
      * Helper method for testing a save operation. This method constructs a
      * configuration from the specified content string. Then it saves this
@@ -305,7 +336,7 @@ public class TestINIConfiguration
     {
         File file = writeTestFile(INI_DATA);
         FileBasedConfigurationBuilder<INIConfiguration> builder =
-                new FileBasedConfigurationBuilder<INIConfiguration>(
+                new FileBasedConfigurationBuilder<>(
                         INIConfiguration.class);
         builder.configure(new FileBasedBuilderParametersImpl()
                 .setFile(file));
@@ -386,7 +417,7 @@ public class TestINIConfiguration
         INIConfiguration instance = new INIConfiguration();
         instance.addProperty("test1.foo", "bar");
         instance.addProperty("test2.foo", "abc");
-        Set<String> expResult = new HashSet<String>();
+        Set<String> expResult = new HashSet<>();
         expResult.add("test1");
         expResult.add("test2");
         Set<String> result = instance.getSections();
@@ -1192,6 +1223,27 @@ public class TestINIConfiguration
                 config.getString("SECTION1.VAR1"));
     }
 
+    /**
+     * Tests whether an empty section can be saved. This is related to
+     * CONFIGURATION-671.
+     */
+    @Test
+    public void testWriteEmptySection()
+            throws ConfigurationException, IOException
+    {
+        final String section = "[EmptySection]";
+        INIConfiguration config = setUpConfig(section);
+        assertEquals("Wrong number of sections", 1,
+                config.getSections().size());
+        assertTrue("Section not found",
+                config.getSections().contains("EmptySection"));
+
+        StringWriter writer = new StringWriter();
+        config.write(writer);
+        assertEquals("Wrong saved configuration",
+                section + LINE_SEPARATOR + LINE_SEPARATOR, writer.toString());
+    }
+
     /**
      * A thread class for testing concurrent access to the global section.
      */
