@@ -45,7 +45,7 @@ import org.junit.Test;
 /**
  * Test case for SubnodeConfiguration.
  *
- * @version $Id: TestSubnodeConfiguration.java 1717717 2015-12-03 07:11:03Z ggregory $
+ * @version $Id: TestSubnodeConfiguration.java 1806832 2017-08-31 17:51:39Z oheger $
  */
 public class TestSubnodeConfiguration
 {
@@ -234,7 +234,7 @@ public class TestSubnodeConfiguration
     public void testGetKeys()
     {
         setUpSubnodeConfig();
-        Set<String> keys = new HashSet<String>();
+        Set<String> keys = new HashSet<>();
         keys.addAll(ConfigurationAssert.keysToList(config));
         assertEquals("Incorrect number of keys", 2, keys.size());
         assertTrue("Key 1 not contained", keys.contains("name"));
@@ -519,4 +519,18 @@ public class TestSubnodeConfiguration
         config.close();
         EasyMock.verify(model);
     }
+
+    /**
+     * Tests whether a correct node model is returned for the sub
+     * configuration. This test is related to CONFIGURATION-670.
+     */
+    @Test
+    public void testGetNodeModel()
+    {
+        setUpSubnodeConfig();
+        InMemoryNodeModel nodeModel = config.getNodeModel();
+
+        assertEquals("Wrong root node", "table",
+                nodeModel.getNodeHandler().getRootNode().getNodeName());
+    }
 }
