@@ -56,7 +56,7 @@ import org.junit.rules.TemporaryFolder;
  * Test class for {@code ReloadingCombinedConfigurationBuilder} which actually
  * accesses files to be reloaded.
  *
- * @version $Id: TestReloadingCombinedConfigurationBuilderFileBased.java 1624601 2014-09-12 18:04:36Z oheger $
+ * @version $Id: TestReloadingCombinedConfigurationBuilderFileBased.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class TestReloadingCombinedConfigurationBuilderFileBased
 {
@@ -332,7 +332,7 @@ public class TestReloadingCombinedConfigurationBuilderFileBased
     {
         File defFile = folder.newFile();
         builder.configure(parameters.combined().setDefinitionBuilder(
-                new ReloadingFileBasedConfigurationBuilder<XMLConfiguration>(
+                new ReloadingFileBasedConfigurationBuilder<>(
                         XMLConfiguration.class).configure(parameters.xml()
                         .setReloadingRefreshDelay(0L).setFile(defFile))));
         checkReloadDefinitionFile(defFile);
