@@ -37,7 +37,7 @@ import org.junit.Test;
 /**
  * Test class for ConfigurationInterpolator.
  *
- * @version $Id: TestConfigurationInterpolator.java 1745634 2016-05-26 19:12:33Z oheger $
+ * @version $Id: TestConfigurationInterpolator.java 1790899 2017-04-10 21:56:46Z ggregory $
  */
 public class TestConfigurationInterpolator
 {
@@ -290,7 +290,7 @@ public class TestConfigurationInterpolator
     {
         Lookup l1 = setUpTestLookup();
         Lookup l2 = setUpTestLookup("someVar", "someValue");
-        Map<String, Lookup> lookups = new HashMap<String, Lookup>();
+        Map<String, Lookup> lookups = new HashMap<>();
         lookups.put(TEST_PREFIX, l1);
         String prefix2 = TEST_PREFIX + "_other";
         lookups.put(prefix2, l2);
@@ -328,7 +328,7 @@ public class TestConfigurationInterpolator
     @Test
     public void testAddDefaultLookups()
     {
-        List<Lookup> lookups = new ArrayList<Lookup>();
+        List<Lookup> lookups = new ArrayList<>();
         lookups.add(setUpTestLookup());
         lookups.add(setUpTestLookup("test", "value"));
         interpolator.addDefaultLookups(lookups);
@@ -367,7 +367,7 @@ public class TestConfigurationInterpolator
     @Test
     public void testRemoveDefaultLookup()
     {
-        List<Lookup> lookups = new ArrayList<Lookup>();
+        List<Lookup> lookups = new ArrayList<>();
         lookups.add(setUpTestLookup());
         lookups.add(setUpTestLookup("test", "value"));
         interpolator.addDefaultLookups(lookups);
