@@ -30,12 +30,13 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
+import org.junit.Assert;
 import org.junit.Test;
 
 /**
  * Test class for {@code ImmutableNode}
  *
- * @version $Id: TestImmutableNode.java 1624601 2014-09-12 18:04:36Z oheger $
+ * @version $Id: TestImmutableNode.java 1792011 2017-04-20 03:17:59Z ggregory $
  */
 public class TestImmutableNode
 {
@@ -137,7 +138,7 @@ public class TestImmutableNode
     public void testNodeWithChildren()
     {
         final int childCount = 8;
-        List<ImmutableNode> childNodes = new ArrayList<ImmutableNode>(childCount);
+        List<ImmutableNode> childNodes = new ArrayList<>(childCount);
         ImmutableNode.Builder builder = new ImmutableNode.Builder(childCount);
         for (int i = 0; i < childCount; i++)
         {
@@ -158,7 +159,7 @@ public class TestImmutableNode
     {
         final int childCount = 4;
         List<ImmutableNode> childNodes =
-                new ArrayList<ImmutableNode>(childCount);
+                new ArrayList<>(childCount);
         for (int i = 0; i < childCount; i++)
         {
             ImmutableNode.Builder childBuilder = new ImmutableNode.Builder();
@@ -231,7 +232,7 @@ public class TestImmutableNode
     {
         ImmutableNode.Builder builder = setUpBuilder();
         final int attrCount = 4;
-        Map<String, Object> attrs = new HashMap<String, Object>();
+        Map<String, Object> attrs = new HashMap<>();
         for (int i = 0; i < attrCount; i++)
         {
             String attrName = NAME + i;
@@ -284,7 +285,7 @@ public class TestImmutableNode
     {
         ImmutableNode.Builder builder = setUpBuilder();
         final int attrCount = 4;
-        Map<String, Object> attrs = new HashMap<String, Object>();
+        Map<String, Object> attrs = new HashMap<>();
         for (int i = 0; i < attrCount; i++)
         {
             String attrName = NAME + i;
@@ -403,6 +404,49 @@ public class TestImmutableNode
         checkChildNodes(node2, node.getChildren().get(0), child2);
     }
 
+    /**
+     * Tests getting named children.
+     */
+    @Test
+    public void testGetChildrenByName()
+    {
+        ImmutableNode node = createDefaultNode(VALUE);
+        ImmutableNode child2 =
+                new ImmutableNode.Builder().name("child2").create();
+        ImmutableNode node2 = node.addChild(child2);
+        checkUpdatedNode(node, node2);
+        assertEquals("child2", node2.getChildren("child2").get(0).getNodeName());
+        assertEquals(child2, node2.getChildren("child2").get(0));
+    }
+
+    /**
+     * Tests getting named children.
+     */
+    @Test
+    public void testGetChildrenByNullName()
+    {
+        ImmutableNode node = createDefaultNode(VALUE);
+        ImmutableNode child2 =
+                new ImmutableNode.Builder().name("child2").create();
+        ImmutableNode node2 = node.addChild(child2);
+        checkUpdatedNode(node, node2);
+        assertTrue(node2.getChildren(null).isEmpty());
+    }
+
+    /**
+     * Tests getting named children.
+     */
+    @Test
+    public void testGetChildrenByMissingName()
+    {
+        ImmutableNode node = createDefaultNode(VALUE);
+        ImmutableNode child2 =
+                new ImmutableNode.Builder().name("child2").create();
+        ImmutableNode node2 = node.addChild(child2);
+        checkUpdatedNode(node, node2);
+        assertTrue(node2.getChildren("NotFound").isEmpty());
+    }
+
     /**
      * Tests whether a new null child node is rejected.
      */
@@ -496,7 +540,7 @@ public class TestImmutableNode
         checkUpdatedNode(node, node2);
         assertSame("Wrong children", node.getChildren(), node2.getChildren());
         Map<String, Object> newAttrs =
-                new HashMap<String, Object>(node.getAttributes());
+                new HashMap<>(node.getAttributes());
         newAttrs.put(ATTR, ATTR_VALUE);
         checkAttributes(node2, newAttrs);
     }
@@ -509,7 +553,7 @@ public class TestImmutableNode
     {
         ImmutableNode.Builder builder = setUpBuilder();
         final String attr2 = ATTR + "_other";
-        Map<String, Object> attrs = new HashMap<String, Object>();
+        Map<String, Object> attrs = new HashMap<>();
         attrs.put(ATTR, ATTR_VALUE);
         attrs.put(attr2, "someValue");
         ImmutableNode node = builder.addAttributes(attrs).create();
@@ -525,7 +569,7 @@ public class TestImmutableNode
     public void testSetAttributes()
     {
         ImmutableNode node = createDefaultNode(VALUE);
-        Map<String, Object> attributes = new HashMap<String, Object>();
+        Map<String, Object> attributes = new HashMap<>();
         attributes.put("newAttribute1", "value1");
         attributes.put("newAttribute2", "value2");
         ImmutableNode node2 = node.setAttributes(attributes);
@@ -614,7 +658,7 @@ public class TestImmutableNode
     {
         final int childCount = 8;
         Collection<ImmutableNode> newChildren =
-                new ArrayList<ImmutableNode>(childCount);
+                new ArrayList<>(childCount);
         for (int i = 0; i < childCount; i++)
         {
             newChildren.add(createChild());
